@@ -6,7 +6,7 @@ from moviepy.decorators import (apply_to_mask,
 @requires_duration
 @apply_to_mask
 @apply_to_audio
-def loop(self, n=None):
+def loop(self, n=None, duration=None):
     """
     Returns a clip that plays the current clip in an infinite loop.
     Ideal for clips coming from gifs.
@@ -16,8 +16,13 @@ def loop(self, n=None):
     n
       Number of times the clip should be played. If `None` the
       the clip will loop indefinitely (i.e. with no set duration).
+
+    duration
+      Total duration of the clip. Can be specified instead of n.
     """
     result = self.fl_time(lambda t: t % self.duration)
     if n:
-        result.duration = n*self.duration
+        duration = n*self.duration
+    if duration:
+        result.duration = duration
     return result
